import{a as t,f as u,t as c,F as i,e as n,k as v,n as o}from"./index-DUEdOLeb.js";var w=u('<div class="embed-wrapper svelte-spagmd"><iframe class="svelte-spagmd"></iframe></div>');function p(s,e){let r=t(e,"url",3,""),d=t(e,"title",3,void 0),m=t(e,"width",3,"100%"),f=t(e,"height",3,"400px"),h=t(e,"allowFullscreen",3,!0);var l=w(),a=n(l);c(()=>{i(a,"src",r()),i(a,"title",d()),v(a,`width: ${m()}; height: ${f()};`),a.allowFullscreen=h()}),o(s,l)}export{p as default};
