# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: a2a.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, "", "a2a.proto")
# @@protoc_insertion_point(imports)


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\ta2a.proto\x12\x06\x61\x32\x61.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xbd\x01\n\x18SendMessageConfiguration\x12\x1d\n\x15\x61\x63\x63\x65pted_output_modes\x18\x01 \x03(\t\x12@\n\x18push_notification_config\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.PushNotificationConfig\x12\x1b\n\x0ehistory_length\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x08\x62locking\x18\x04 \x01(\x08\x42\x11\n\x0f_history_length"\xcb\x01\n\x04Task\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\ncontext_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\'\n\x06status\x18\x03 \x01(\x0b\x32\x12.a2a.v1.TaskStatusB\x03\xe0\x41\x02\x12#\n\tartifacts\x18\x04 \x03(\x0b\x32\x10.a2a.v1.Artifact\x12 \n\x07history\x18\x05 \x03(\x0b\x32\x0f.a2a.v1.Message\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct"\x84\x01\n\nTaskStatus\x12%\n\x05state\x18\x01 \x01(\x0e\x32\x11.a2a.v1.TaskStateB\x03\xe0\x41\x02\x12 \n\x07message\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.Message\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\x8d\x01\n\x04Part\x12\x0e\n\x04text\x18\x01 \x01(\tH\x00\x12 \n\x04\x66ile\x18\x02 \x01(\x0b\x32\x10.a2a.v1.FilePartH\x00\x12 \n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x10.a2a.v1.DataPartH\x00\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x06\n\x04part"h\n\x08\x46ilePart\x12\x17\n\rfile_with_uri\x18\x01 \x01(\tH\x00\x12\x19\n\x0f\x66ile_with_bytes\x18\x02 \x01(\x0cH\x00\x12\x12\n\nmedia_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\tB\x06\n\x04\x66ile"6\n\x08\x44\x61taPart\x12*\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02"\xe5\x01\n\x07Message\x12\x17\n\nmessage_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\ncontext_id\x18\x02 \x01(\t\x12\x0f\n\x07task_id\x18\x03 \x01(\t\x12\x1f\n\x04role\x18\x04 \x01(\x0e\x32\x0c.a2a.v1.RoleB\x03\xe0\x41\x02\x12 \n\x05parts\x18\x05 \x03(\x0b\x32\x0c.a2a.v1.PartB\x03\xe0\x41\x02\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nextensions\x18\x07 \x03(\t\x12\x1a\n\x12reference_task_ids\x18\x08 \x03(\t"\xa8\x01\n\x08\x41rtifact\x12\x18\n\x0b\x61rtifact_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12 \n\x05parts\x18\x05 \x03(\x0b\x32\x0c.a2a.v1.PartB\x03\xe0\x41\x02\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nextensions\x18\x07 \x03(\t"\xae\x01\n\x15TaskStatusUpdateEvent\x12\x14\n\x07task_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\ncontext_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\'\n\x06status\x18\x03 \x01(\x0b\x32\x12.a2a.v1.TaskStatusB\x03\xe0\x41\x02\x12\x12\n\x05\x66inal\x18\x04 \x01(\x08\x42\x03\xe0\x41\x02\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct"\xc0\x01\n\x17TaskArtifactUpdateEvent\x12\x14\n\x07task_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x17\n\ncontext_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\'\n\x08\x61rtifact\x18\x03 \x01(\x0b\x32\x10.a2a.v1.ArtifactB\x03\xe0\x41\x02\x12\x0e\n\x06\x61ppend\x18\x04 \x01(\x08\x12\x12\n\nlast_chunk\x18\x05 \x01(\x08\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct"y\n\x16PushNotificationConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x03url\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05token\x18\x03 \x01(\t\x12\x32\n\x0e\x61uthentication\x18\x04 \x01(\x0b\x32\x1a.a2a.v1.AuthenticationInfo"?\n\x12\x41uthenticationInfo\x12\x14\n\x07schemes\x18\x01 \x03(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x63redentials\x18\x02 \x01(\t"Q\n\x0e\x41gentInterface\x12\x10\n\x03url\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1d\n\x10protocol_binding\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x0e\n\x06tenant\x18\x03 \x01(\t"\xc8\x05\n\tAgentCard\x12\x1e\n\x11protocol_versions\x18\x10 \x03(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x39\n\x14supported_interfaces\x18\x13 \x03(\x0b\x32\x16.a2a.v1.AgentInterfaceB\x03\xe0\x41\x02\x12\'\n\x08provider\x18\x04 \x01(\x0b\x32\x15.a2a.v1.AgentProvider\x12\x14\n\x07version\x18\x05 \x01(\tB\x03\xe0\x41\x02\x12\x1e\n\x11\x64ocumentation_url\x18\x06 \x01(\tH\x00\x88\x01\x01\x12\x34\n\x0c\x63\x61pabilities\x18\x07 \x01(\x0b\x32\x19.a2a.v1.AgentCapabilitiesB\x03\xe0\x41\x02\x12@\n\x10security_schemes\x18\x08 \x03(\x0b\x32&.a2a.v1.AgentCard.SecuritySchemesEntry\x12"\n\x08security\x18\t \x03(\x0b\x32\x10.a2a.v1.Security\x12 \n\x13\x64\x65\x66\x61ult_input_modes\x18\n \x03(\tB\x03\xe0\x41\x02\x12!\n\x14\x64\x65\x66\x61ult_output_modes\x18\x0b \x03(\tB\x03\xe0\x41\x02\x12\'\n\x06skills\x18\x0c \x03(\x0b\x32\x12.a2a.v1.AgentSkillB\x03\xe0\x41\x02\x12.\n\nsignatures\x18\x11 \x03(\x0b\x32\x1a.a2a.v1.AgentCardSignature\x12\x15\n\x08icon_url\x18\x12 \x01(\tH\x01\x88\x01\x01\x1aN\n\x14SecuritySchemesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.a2a.v1.SecurityScheme:\x02\x38\x01\x42\x14\n\x12_documentation_urlB\x0b\n\t_icon_urlJ\x04\x08\x03\x10\x04J\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10"<\n\rAgentProvider\x12\x10\n\x03url\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x19\n\x0corganization\x18\x02 \x01(\tB\x03\xe0\x41\x02"\x9b\x02\n\x11\x41gentCapabilities\x12\x16\n\tstreaming\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12push_notifications\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12*\n\nextensions\x18\x03 \x03(\x0b\x32\x16.a2a.v1.AgentExtension\x12%\n\x18state_transition_history\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12 \n\x13\x65xtended_agent_card\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x0c\n\n_streamingB\x15\n\x13_push_notificationsB\x1b\n\x19_state_transition_historyB\x16\n\x14_extended_agent_card"m\n\x0e\x41gentExtension\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\'\n\x06params\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct"\xbe\x01\n\nAgentSkill\x12\x0f\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04tags\x18\x04 \x03(\tB\x03\xe0\x41\x02\x12\x10\n\x08\x65xamples\x18\x05 \x03(\t\x12\x13\n\x0binput_modes\x18\x06 \x03(\t\x12\x14\n\x0coutput_modes\x18\x07 \x03(\t\x12"\n\x08security\x18\x08 \x03(\x0b\x32\x10.a2a.v1.Security"m\n\x12\x41gentCardSignature\x12\x16\n\tprotected\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tsignature\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\'\n\x06header\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"v\n\x1aTaskPushNotificationConfig\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x45\n\x18push_notification_config\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.PushNotificationConfigB\x03\xe0\x41\x02"\x1a\n\nStringList\x12\x0c\n\x04list\x18\x01 \x03(\t"~\n\x08Security\x12.\n\x07schemes\x18\x01 \x03(\x0b\x32\x1d.a2a.v1.Security.SchemesEntry\x1a\x42\n\x0cSchemesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.a2a.v1.StringList:\x02\x38\x01"\xf1\x02\n\x0eSecurityScheme\x12?\n\x17\x61pi_key_security_scheme\x18\x01 \x01(\x0b\x32\x1c.a2a.v1.APIKeySecuritySchemeH\x00\x12\x43\n\x19http_auth_security_scheme\x18\x02 \x01(\x0b\x32\x1e.a2a.v1.HTTPAuthSecuritySchemeH\x00\x12>\n\x16oauth2_security_scheme\x18\x03 \x01(\x0b\x32\x1c.a2a.v1.OAuth2SecuritySchemeH\x00\x12N\n\x1fopen_id_connect_security_scheme\x18\x04 \x01(\x0b\x32#.a2a.v1.OpenIdConnectSecuritySchemeH\x00\x12?\n\x14mtls_security_scheme\x18\x05 \x01(\x0b\x32\x1f.a2a.v1.MutualTlsSecuritySchemeH\x00\x42\x08\n\x06scheme"U\n\x14\x41PIKeySecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x15\n\x08location\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\x04name\x18\x03 \x01(\tB\x03\xe0\x41\x02"Y\n\x16HTTPAuthSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x13\n\x06scheme\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\rbearer_format\x18\x03 \x01(\t"p\n\x14OAuth2SecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12&\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.a2a.v1.OAuthFlowsB\x03\xe0\x41\x02\x12\x1b\n\x13oauth2_metadata_url\x18\x03 \x01(\t"T\n\x1bOpenIdConnectSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12 \n\x13open_id_connect_url\x18\x02 \x01(\tB\x03\xe0\x41\x02".\n\x17MutualTlsSecurityScheme\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t"\xd8\x01\n\nOAuthFlows\x12@\n\x12\x61uthorization_code\x18\x01 \x01(\x0b\x32".a2a.v1.AuthorizationCodeOAuthFlowH\x00\x12@\n\x12\x63lient_credentials\x18\x02 \x01(\x0b\x32".a2a.v1.ClientCredentialsOAuthFlowH\x00\x12\x32\n\x0b\x64\x65vice_code\x18\x05 \x01(\x0b\x32\x1b.a2a.v1.DeviceCodeOAuthFlowH\x00\x42\x06\n\x04\x66lowJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05"\xf4\x01\n\x1a\x41uthorizationCodeOAuthFlow\x12\x1e\n\x11\x61uthorization_url\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\ttoken_url\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0brefresh_url\x18\x03 \x01(\t\x12\x43\n\x06scopes\x18\x04 \x03(\x0b\x32..a2a.v1.AuthorizationCodeOAuthFlow.ScopesEntryB\x03\xe0\x41\x02\x12\x15\n\rpkce_required\x18\x05 \x01(\x08\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xbd\x01\n\x1a\x43lientCredentialsOAuthFlow\x12\x16\n\ttoken_url\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0brefresh_url\x18\x02 \x01(\t\x12\x43\n\x06scopes\x18\x03 \x03(\x0b\x32..a2a.v1.ClientCredentialsOAuthFlow.ScopesEntryB\x03\xe0\x41\x02\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xd6\x01\n\x13\x44\x65viceCodeOAuthFlow\x12%\n\x18\x64\x65vice_authorization_url\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\ttoken_url\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0brefresh_url\x18\x03 \x01(\t\x12<\n\x06scopes\x18\x04 \x03(\x0b\x32\'.a2a.v1.DeviceCodeOAuthFlow.ScopesEntryB\x03\xe0\x41\x02\x1a-\n\x0bScopesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xaf\x01\n\x12SendMessageRequest\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12%\n\x07message\x18\x01 \x01(\x0b\x32\x0f.a2a.v1.MessageB\x03\xe0\x41\x02\x12\x37\n\rconfiguration\x18\x02 \x01(\x0b\x32 .a2a.v1.SendMessageConfiguration\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct"c\n\x0eGetTaskRequest\x12\x0e\n\x06tenant\x18\x03 \x01(\t\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1b\n\x0ehistory_length\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\x11\n\x0f_history_length"\xb5\x02\n\x10ListTasksRequest\x12\x0e\n\x06tenant\x18\t \x01(\t\x12\x12\n\ncontext_id\x18\x01 \x01(\t\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.a2a.v1.TaskState\x12\x16\n\tpage_size\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x1b\n\x0ehistory_length\x18\x05 \x01(\x05H\x01\x88\x01\x01\x12:\n\x16status_timestamp_after\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x11include_artifacts\x18\x07 \x01(\x08H\x02\x88\x01\x01\x42\x0c\n\n_page_sizeB\x11\n\x0f_history_lengthB\x14\n\x12_include_artifacts"\x84\x01\n\x11ListTasksResponse\x12 \n\x05tasks\x18\x01 \x03(\x0b\x32\x0c.a2a.v1.TaskB\x03\xe0\x41\x02\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x02\x12\x17\n\ntotal_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x02"1\n\x11\x43\x61ncelTaskRequest\x12\x0e\n\x06tenant\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t"D\n$GetTaskPushNotificationConfigRequest\x12\x0e\n\x06tenant\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t"G\n\'DeleteTaskPushNotificationConfigRequest\x12\x0e\n\x06tenant\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t"\x9c\x01\n$SetTaskPushNotificationConfigRequest\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tconfig_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x37\n\x06\x63onfig\x18\x03 \x01(\x0b\x32".a2a.v1.TaskPushNotificationConfigB\x03\xe0\x41\x02"6\n\x16SubscribeToTaskRequest\x12\x0e\n\x06tenant\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t"n\n%ListTaskPushNotificationConfigRequest\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"-\n\x1bGetExtendedAgentCardRequest\x12\x0e\n\x06tenant\x18\x01 \x01(\t"b\n\x13SendMessageResponse\x12\x1c\n\x04task\x18\x01 \x01(\x0b\x32\x0c.a2a.v1.TaskH\x00\x12"\n\x07message\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.MessageH\x00\x42\t\n\x07payload"\xd1\x01\n\x0eStreamResponse\x12\x1c\n\x04task\x18\x01 \x01(\x0b\x32\x0c.a2a.v1.TaskH\x00\x12"\n\x07message\x18\x02 \x01(\x0b\x32\x0f.a2a.v1.MessageH\x00\x12\x36\n\rstatus_update\x18\x03 \x01(\x0b\x32\x1d.a2a.v1.TaskStatusUpdateEventH\x00\x12:\n\x0f\x61rtifact_update\x18\x04 \x01(\x0b\x32\x1f.a2a.v1.TaskArtifactUpdateEventH\x00\x42\t\n\x07payload"v\n&ListTaskPushNotificationConfigResponse\x12\x33\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32".a2a.v1.TaskPushNotificationConfig\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*\xfa\x01\n\tTaskState\x12\x1a\n\x16TASK_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14TASK_STATE_SUBMITTED\x10\x01\x12\x16\n\x12TASK_STATE_WORKING\x10\x02\x12\x18\n\x14TASK_STATE_COMPLETED\x10\x03\x12\x15\n\x11TASK_STATE_FAILED\x10\x04\x12\x18\n\x14TASK_STATE_CANCELLED\x10\x05\x12\x1d\n\x19TASK_STATE_INPUT_REQUIRED\x10\x06\x12\x17\n\x13TASK_STATE_REJECTED\x10\x07\x12\x1c\n\x18TASK_STATE_AUTH_REQUIRED\x10\x08*;\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\r\n\tROLE_USER\x10\x01\x12\x0e\n\nROLE_AGENT\x10\x02\x32\xbe\x0e\n\nA2AService\x12}\n\x0bSendMessage\x12\x1a.a2a.v1.SendMessageRequest\x1a\x1b.a2a.v1.SendMessageResponse"5\x82\xd3\xe4\x93\x02/"\r/message:send:\x01*Z\x1b"\x16/{tenant}/message:send:\x01*\x12\x87\x01\n\x14SendStreamingMessage\x12\x1a.a2a.v1.SendMessageRequest\x1a\x16.a2a.v1.StreamResponse"9\x82\xd3\xe4\x93\x02\x33"\x0f/message:stream:\x01*Z\x1d"\x18/{tenant}/message:stream:\x01*0\x01\x12k\n\x07GetTask\x12\x16.a2a.v1.GetTaskRequest\x1a\x0c.a2a.v1.Task":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\x12\x0f/{name=tasks/*}Z\x1a\x12\x18/{tenant}/{name=tasks/*}\x12\x63\n\tListTasks\x12\x18.a2a.v1.ListTasksRequest\x1a\x19.a2a.v1.ListTasksResponse"!\x82\xd3\xe4\x93\x02\x1b\x12\x06/tasksZ\x11\x12\x0f/{tenant}/tasks\x12~\n\nCancelTask\x12\x19.a2a.v1.CancelTaskRequest\x1a\x0c.a2a.v1.Task"G\x82\xd3\xe4\x93\x02\x41"\x16/{name=tasks/*}:cancel:\x01*Z$"\x1f/{tenant}/{name=tasks/*}:cancel:\x01*\x12\x94\x01\n\x0fSubscribeToTask\x12\x1e.a2a.v1.SubscribeToTaskRequest\x1a\x16.a2a.v1.StreamResponse"G\x82\xd3\xe4\x93\x02\x41\x12\x19/{name=tasks/*}:subscribeZ$\x12"/{tenant}/{name=tasks/*}:subscribe0\x01\x12\xfb\x01\n\x1dSetTaskPushNotificationConfig\x12,.a2a.v1.SetTaskPushNotificationConfigRequest\x1a".a2a.v1.TaskPushNotificationConfig"\x87\x01\xda\x41\rparent,config\x82\xd3\xe4\x93\x02q")/{parent=tasks/*/pushNotificationConfigs}:\x06\x63onfigZ<"2/{tenant}/{parent=tasks/*/pushNotificationConfigs}:\x06\x63onfig\x12\xe1\x01\n\x1dGetTaskPushNotificationConfig\x12,.a2a.v1.GetTaskPushNotificationConfigRequest\x1a".a2a.v1.TaskPushNotificationConfig"n\xda\x41\x04name\x82\xd3\xe4\x93\x02\x61\x12)/{name=tasks/*/pushNotificationConfigs/*}Z4\x12\x32/{tenant}/{name=tasks/*/pushNotificationConfigs/*}\x12\xf1\x01\n\x1eListTaskPushNotificationConfig\x12-.a2a.v1.ListTaskPushNotificationConfigRequest\x1a..a2a.v1.ListTaskPushNotificationConfigResponse"p\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x61\x12)/{parent=tasks/*}/pushNotificationConfigsZ4\x12\x32/{tenant}/{parent=tasks/*}/pushNotificationConfigs\x12\x89\x01\n\x14GetExtendedAgentCard\x12#.a2a.v1.GetExtendedAgentCardRequest\x1a\x11.a2a.v1.AgentCard"9\x82\xd3\xe4\x93\x02\x33\x12\x12/extendedAgentCardZ\x1d\x12\x1b/{tenant}/extendedAgentCard\x12\xdb\x01\n DeleteTaskPushNotificationConfig\x12/.a2a.v1.DeleteTaskPushNotificationConfigRequest\x1a\x16.google.protobuf.Empty"n\xda\x41\x04name\x82\xd3\xe4\x93\x02\x61*)/{name=tasks/*/pushNotificationConfigs/*}Z4*2/{tenant}/{name=tasks/*/pushNotificationConfigs/*}B=\n\x11\x63om.google.a2a.v1B\x03\x41\x32\x41P\x01Z\x18google.golang.org/a2a/v1\xaa\x02\x06\x41\x32\x61.V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "a2a_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\021com.google.a2a.v1B\003A2AP\001Z\030google.golang.org/a2a/v1\252\002\006A2a.V1"
    _globals["_TASK"].fields_by_name["id"]._loaded_options = None
    _globals["_TASK"].fields_by_name["id"]._serialized_options = b"\340A\002"
    _globals["_TASK"].fields_by_name["context_id"]._loaded_options = None
    _globals["_TASK"].fields_by_name["context_id"]._serialized_options = b"\340A\002"
    _globals["_TASK"].fields_by_name["status"]._loaded_options = None
    _globals["_TASK"].fields_by_name["status"]._serialized_options = b"\340A\002"
    _globals["_TASKSTATUS"].fields_by_name["state"]._loaded_options = None
    _globals["_TASKSTATUS"].fields_by_name["state"]._serialized_options = b"\340A\002"
    _globals["_DATAPART"].fields_by_name["data"]._loaded_options = None
    _globals["_DATAPART"].fields_by_name["data"]._serialized_options = b"\340A\002"
    _globals["_MESSAGE"].fields_by_name["message_id"]._loaded_options = None
    _globals["_MESSAGE"].fields_by_name["message_id"]._serialized_options = b"\340A\002"
    _globals["_MESSAGE"].fields_by_name["role"]._loaded_options = None
    _globals["_MESSAGE"].fields_by_name["role"]._serialized_options = b"\340A\002"
    _globals["_MESSAGE"].fields_by_name["parts"]._loaded_options = None
    _globals["_MESSAGE"].fields_by_name["parts"]._serialized_options = b"\340A\002"
    _globals["_ARTIFACT"].fields_by_name["artifact_id"]._loaded_options = None
    _globals["_ARTIFACT"].fields_by_name["artifact_id"]._serialized_options = b"\340A\002"
    _globals["_ARTIFACT"].fields_by_name["parts"]._loaded_options = None
    _globals["_ARTIFACT"].fields_by_name["parts"]._serialized_options = b"\340A\002"
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["task_id"]._loaded_options = None
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["task_id"]._serialized_options = b"\340A\002"
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["context_id"]._loaded_options = None
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["context_id"]._serialized_options = b"\340A\002"
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["status"]._loaded_options = None
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["status"]._serialized_options = b"\340A\002"
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["final"]._loaded_options = None
    _globals["_TASKSTATUSUPDATEEVENT"].fields_by_name["final"]._serialized_options = b"\340A\002"
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["task_id"]._loaded_options = None
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["task_id"]._serialized_options = b"\340A\002"
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["context_id"]._loaded_options = None
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["context_id"]._serialized_options = b"\340A\002"
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["artifact"]._loaded_options = None
    _globals["_TASKARTIFACTUPDATEEVENT"].fields_by_name["artifact"]._serialized_options = b"\340A\002"
    _globals["_PUSHNOTIFICATIONCONFIG"].fields_by_name["url"]._loaded_options = None
    _globals["_PUSHNOTIFICATIONCONFIG"].fields_by_name["url"]._serialized_options = b"\340A\002"
    _globals["_AUTHENTICATIONINFO"].fields_by_name["schemes"]._loaded_options = None
    _globals["_AUTHENTICATIONINFO"].fields_by_name["schemes"]._serialized_options = b"\340A\002"
    _globals["_AGENTINTERFACE"].fields_by_name["url"]._loaded_options = None
    _globals["_AGENTINTERFACE"].fields_by_name["url"]._serialized_options = b"\340A\002"
    _globals["_AGENTINTERFACE"].fields_by_name["protocol_binding"]._loaded_options = None
    _globals["_AGENTINTERFACE"].fields_by_name["protocol_binding"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._loaded_options = None
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_options = b"8\001"
    _globals["_AGENTCARD"].fields_by_name["protocol_versions"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["protocol_versions"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["name"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["name"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["description"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["description"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["supported_interfaces"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["supported_interfaces"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["version"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["version"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["capabilities"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["capabilities"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["default_input_modes"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["default_input_modes"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["default_output_modes"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["default_output_modes"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARD"].fields_by_name["skills"]._loaded_options = None
    _globals["_AGENTCARD"].fields_by_name["skills"]._serialized_options = b"\340A\002"
    _globals["_AGENTPROVIDER"].fields_by_name["url"]._loaded_options = None
    _globals["_AGENTPROVIDER"].fields_by_name["url"]._serialized_options = b"\340A\002"
    _globals["_AGENTPROVIDER"].fields_by_name["organization"]._loaded_options = None
    _globals["_AGENTPROVIDER"].fields_by_name["organization"]._serialized_options = b"\340A\002"
    _globals["_AGENTSKILL"].fields_by_name["id"]._loaded_options = None
    _globals["_AGENTSKILL"].fields_by_name["id"]._serialized_options = b"\340A\002"
    _globals["_AGENTSKILL"].fields_by_name["name"]._loaded_options = None
    _globals["_AGENTSKILL"].fields_by_name["name"]._serialized_options = b"\340A\002"
    _globals["_AGENTSKILL"].fields_by_name["description"]._loaded_options = None
    _globals["_AGENTSKILL"].fields_by_name["description"]._serialized_options = b"\340A\002"
    _globals["_AGENTSKILL"].fields_by_name["tags"]._loaded_options = None
    _globals["_AGENTSKILL"].fields_by_name["tags"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["protected"]._loaded_options = None
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["protected"]._serialized_options = b"\340A\002"
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["signature"]._loaded_options = None
    _globals["_AGENTCARDSIGNATURE"].fields_by_name["signature"]._serialized_options = b"\340A\002"
    _globals["_TASKPUSHNOTIFICATIONCONFIG"].fields_by_name["name"]._loaded_options = None
    _globals["_TASKPUSHNOTIFICATIONCONFIG"].fields_by_name["name"]._serialized_options = b"\340A\002"
    _globals["_TASKPUSHNOTIFICATIONCONFIG"].fields_by_name["push_notification_config"]._loaded_options = None
    _globals["_TASKPUSHNOTIFICATIONCONFIG"].fields_by_name[
        "push_notification_config"
    ]._serialized_options = b"\340A\002"
    _globals["_SECURITY_SCHEMESENTRY"]._loaded_options = None
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_options = b"8\001"
    _globals["_APIKEYSECURITYSCHEME"].fields_by_name["location"]._loaded_options = None
    _globals["_APIKEYSECURITYSCHEME"].fields_by_name["location"]._serialized_options = b"\340A\002"
    _globals["_APIKEYSECURITYSCHEME"].fields_by_name["name"]._loaded_options = None
    _globals["_APIKEYSECURITYSCHEME"].fields_by_name["name"]._serialized_options = b"\340A\002"
    _globals["_HTTPAUTHSECURITYSCHEME"].fields_by_name["scheme"]._loaded_options = None
    _globals["_HTTPAUTHSECURITYSCHEME"].fields_by_name["scheme"]._serialized_options = b"\340A\002"
    _globals["_OAUTH2SECURITYSCHEME"].fields_by_name["flows"]._loaded_options = None
    _globals["_OAUTH2SECURITYSCHEME"].fields_by_name["flows"]._serialized_options = b"\340A\002"
    _globals["_OPENIDCONNECTSECURITYSCHEME"].fields_by_name["open_id_connect_url"]._loaded_options = None
    _globals["_OPENIDCONNECTSECURITYSCHEME"].fields_by_name["open_id_connect_url"]._serialized_options = b"\340A\002"
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["authorization_url"]._loaded_options = None
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["authorization_url"]._serialized_options = b"\340A\002"
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["token_url"]._loaded_options = None
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["token_url"]._serialized_options = b"\340A\002"
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["scopes"]._loaded_options = None
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"].fields_by_name["scopes"]._serialized_options = b"\340A\002"
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"].fields_by_name["token_url"]._loaded_options = None
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"].fields_by_name["token_url"]._serialized_options = b"\340A\002"
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"].fields_by_name["scopes"]._loaded_options = None
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"].fields_by_name["scopes"]._serialized_options = b"\340A\002"
    _globals["_DEVICECODEOAUTHFLOW_SCOPESENTRY"]._loaded_options = None
    _globals["_DEVICECODEOAUTHFLOW_SCOPESENTRY"]._serialized_options = b"8\001"
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["device_authorization_url"]._loaded_options = None
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["device_authorization_url"]._serialized_options = b"\340A\002"
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["token_url"]._loaded_options = None
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["token_url"]._serialized_options = b"\340A\002"
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["scopes"]._loaded_options = None
    _globals["_DEVICECODEOAUTHFLOW"].fields_by_name["scopes"]._serialized_options = b"\340A\002"
    _globals["_SENDMESSAGEREQUEST"].fields_by_name["message"]._loaded_options = None
    _globals["_SENDMESSAGEREQUEST"].fields_by_name["message"]._serialized_options = b"\340A\002"
    _globals["_GETTASKREQUEST"].fields_by_name["name"]._loaded_options = None
    _globals["_GETTASKREQUEST"].fields_by_name["name"]._serialized_options = b"\340A\002"
    _globals["_LISTTASKSRESPONSE"].fields_by_name["tasks"]._loaded_options = None
    _globals["_LISTTASKSRESPONSE"].fields_by_name["tasks"]._serialized_options = b"\340A\002"
    _globals["_LISTTASKSRESPONSE"].fields_by_name["next_page_token"]._loaded_options = None
    _globals["_LISTTASKSRESPONSE"].fields_by_name["next_page_token"]._serialized_options = b"\340A\002"
    _globals["_LISTTASKSRESPONSE"].fields_by_name["page_size"]._loaded_options = None
    _globals["_LISTTASKSRESPONSE"].fields_by_name["page_size"]._serialized_options = b"\340A\002"
    _globals["_LISTTASKSRESPONSE"].fields_by_name["total_size"]._loaded_options = None
    _globals["_LISTTASKSRESPONSE"].fields_by_name["total_size"]._serialized_options = b"\340A\002"
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["parent"]._loaded_options = None
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["parent"]._serialized_options = b"\340A\002"
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["config_id"]._loaded_options = None
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["config_id"]._serialized_options = b"\340A\002"
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["config"]._loaded_options = None
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"].fields_by_name["config"]._serialized_options = b"\340A\002"
    _globals["_A2ASERVICE"].methods_by_name["SendMessage"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SendMessage"
    ]._serialized_options = b'\202\323\344\223\002/"\r/message:send:\001*Z\033"\026/{tenant}/message:send:\001*'
    _globals["_A2ASERVICE"].methods_by_name["SendStreamingMessage"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SendStreamingMessage"
    ]._serialized_options = b'\202\323\344\223\0023"\017/message:stream:\001*Z\035"\030/{tenant}/message:stream:\001*'
    _globals["_A2ASERVICE"].methods_by_name["GetTask"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetTask"
    ]._serialized_options = (
        b"\332A\004name\202\323\344\223\002-\022\017/{name=tasks/*}Z\032\022\030/{tenant}/{name=tasks/*}"
    )
    _globals["_A2ASERVICE"].methods_by_name["ListTasks"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "ListTasks"
    ]._serialized_options = b"\202\323\344\223\002\033\022\006/tasksZ\021\022\017/{tenant}/tasks"
    _globals["_A2ASERVICE"].methods_by_name["CancelTask"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "CancelTask"
    ]._serialized_options = (
        b'\202\323\344\223\002A"\026/{name=tasks/*}:cancel:\001*Z$"\037/{tenant}/{name=tasks/*}:cancel:\001*'
    )
    _globals["_A2ASERVICE"].methods_by_name["SubscribeToTask"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SubscribeToTask"
    ]._serialized_options = (
        b'\202\323\344\223\002A\022\031/{name=tasks/*}:subscribeZ$\022"/{tenant}/{name=tasks/*}:subscribe'
    )
    _globals["_A2ASERVICE"].methods_by_name["SetTaskPushNotificationConfig"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "SetTaskPushNotificationConfig"
    ]._serialized_options = b'\332A\rparent,config\202\323\344\223\002q")/{parent=tasks/*/pushNotificationConfigs}:\006configZ<"2/{tenant}/{parent=tasks/*/pushNotificationConfigs}:\006config'
    _globals["_A2ASERVICE"].methods_by_name["GetTaskPushNotificationConfig"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\004name\202\323\344\223\002a\022)/{name=tasks/*/pushNotificationConfigs/*}Z4\0222/{tenant}/{name=tasks/*/pushNotificationConfigs/*}"
    _globals["_A2ASERVICE"].methods_by_name["ListTaskPushNotificationConfig"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "ListTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\006parent\202\323\344\223\002a\022)/{parent=tasks/*}/pushNotificationConfigsZ4\0222/{tenant}/{parent=tasks/*}/pushNotificationConfigs"
    _globals["_A2ASERVICE"].methods_by_name["GetExtendedAgentCard"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "GetExtendedAgentCard"
    ]._serialized_options = b"\202\323\344\223\0023\022\022/extendedAgentCardZ\035\022\033/{tenant}/extendedAgentCard"
    _globals["_A2ASERVICE"].methods_by_name["DeleteTaskPushNotificationConfig"]._loaded_options = None
    _globals["_A2ASERVICE"].methods_by_name[
        "DeleteTaskPushNotificationConfig"
    ]._serialized_options = b"\332A\004name\202\323\344\223\002a*)/{name=tasks/*/pushNotificationConfigs/*}Z4*2/{tenant}/{name=tasks/*/pushNotificationConfigs/*}"
    _globals["_TASKSTATE"]._serialized_start = 7240
    _globals["_TASKSTATE"]._serialized_end = 7490
    _globals["_ROLE"]._serialized_start = 7492
    _globals["_ROLE"]._serialized_end = 7551
    _globals["_SENDMESSAGECONFIGURATION"]._serialized_start = 202
    _globals["_SENDMESSAGECONFIGURATION"]._serialized_end = 391
    _globals["_TASK"]._serialized_start = 394
    _globals["_TASK"]._serialized_end = 597
    _globals["_TASKSTATUS"]._serialized_start = 600
    _globals["_TASKSTATUS"]._serialized_end = 732
    _globals["_PART"]._serialized_start = 735
    _globals["_PART"]._serialized_end = 876
    _globals["_FILEPART"]._serialized_start = 878
    _globals["_FILEPART"]._serialized_end = 982
    _globals["_DATAPART"]._serialized_start = 984
    _globals["_DATAPART"]._serialized_end = 1038
    _globals["_MESSAGE"]._serialized_start = 1041
    _globals["_MESSAGE"]._serialized_end = 1270
    _globals["_ARTIFACT"]._serialized_start = 1273
    _globals["_ARTIFACT"]._serialized_end = 1441
    _globals["_TASKSTATUSUPDATEEVENT"]._serialized_start = 1444
    _globals["_TASKSTATUSUPDATEEVENT"]._serialized_end = 1618
    _globals["_TASKARTIFACTUPDATEEVENT"]._serialized_start = 1621
    _globals["_TASKARTIFACTUPDATEEVENT"]._serialized_end = 1813
    _globals["_PUSHNOTIFICATIONCONFIG"]._serialized_start = 1815
    _globals["_PUSHNOTIFICATIONCONFIG"]._serialized_end = 1936
    _globals["_AUTHENTICATIONINFO"]._serialized_start = 1938
    _globals["_AUTHENTICATIONINFO"]._serialized_end = 2001
    _globals["_AGENTINTERFACE"]._serialized_start = 2003
    _globals["_AGENTINTERFACE"]._serialized_end = 2084
    _globals["_AGENTCARD"]._serialized_start = 2087
    _globals["_AGENTCARD"]._serialized_end = 2799
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_start = 2668
    _globals["_AGENTCARD_SECURITYSCHEMESENTRY"]._serialized_end = 2746
    _globals["_AGENTPROVIDER"]._serialized_start = 2801
    _globals["_AGENTPROVIDER"]._serialized_end = 2861
    _globals["_AGENTCAPABILITIES"]._serialized_start = 2864
    _globals["_AGENTCAPABILITIES"]._serialized_end = 3147
    _globals["_AGENTEXTENSION"]._serialized_start = 3149
    _globals["_AGENTEXTENSION"]._serialized_end = 3258
    _globals["_AGENTSKILL"]._serialized_start = 3261
    _globals["_AGENTSKILL"]._serialized_end = 3451
    _globals["_AGENTCARDSIGNATURE"]._serialized_start = 3453
    _globals["_AGENTCARDSIGNATURE"]._serialized_end = 3562
    _globals["_TASKPUSHNOTIFICATIONCONFIG"]._serialized_start = 3564
    _globals["_TASKPUSHNOTIFICATIONCONFIG"]._serialized_end = 3682
    _globals["_STRINGLIST"]._serialized_start = 3684
    _globals["_STRINGLIST"]._serialized_end = 3710
    _globals["_SECURITY"]._serialized_start = 3712
    _globals["_SECURITY"]._serialized_end = 3838
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_start = 3772
    _globals["_SECURITY_SCHEMESENTRY"]._serialized_end = 3838
    _globals["_SECURITYSCHEME"]._serialized_start = 3841
    _globals["_SECURITYSCHEME"]._serialized_end = 4210
    _globals["_APIKEYSECURITYSCHEME"]._serialized_start = 4212
    _globals["_APIKEYSECURITYSCHEME"]._serialized_end = 4297
    _globals["_HTTPAUTHSECURITYSCHEME"]._serialized_start = 4299
    _globals["_HTTPAUTHSECURITYSCHEME"]._serialized_end = 4388
    _globals["_OAUTH2SECURITYSCHEME"]._serialized_start = 4390
    _globals["_OAUTH2SECURITYSCHEME"]._serialized_end = 4502
    _globals["_OPENIDCONNECTSECURITYSCHEME"]._serialized_start = 4504
    _globals["_OPENIDCONNECTSECURITYSCHEME"]._serialized_end = 4588
    _globals["_MUTUALTLSSECURITYSCHEME"]._serialized_start = 4590
    _globals["_MUTUALTLSSECURITYSCHEME"]._serialized_end = 4636
    _globals["_OAUTHFLOWS"]._serialized_start = 4639
    _globals["_OAUTHFLOWS"]._serialized_end = 4855
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"]._serialized_start = 4858
    _globals["_AUTHORIZATIONCODEOAUTHFLOW"]._serialized_end = 5102
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_start = 5057
    _globals["_AUTHORIZATIONCODEOAUTHFLOW_SCOPESENTRY"]._serialized_end = 5102
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"]._serialized_start = 5105
    _globals["_CLIENTCREDENTIALSOAUTHFLOW"]._serialized_end = 5294
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_start = 5057
    _globals["_CLIENTCREDENTIALSOAUTHFLOW_SCOPESENTRY"]._serialized_end = 5102
    _globals["_DEVICECODEOAUTHFLOW"]._serialized_start = 5297
    _globals["_DEVICECODEOAUTHFLOW"]._serialized_end = 5511
    _globals["_DEVICECODEOAUTHFLOW_SCOPESENTRY"]._serialized_start = 5057
    _globals["_DEVICECODEOAUTHFLOW_SCOPESENTRY"]._serialized_end = 5102
    _globals["_SENDMESSAGEREQUEST"]._serialized_start = 5514
    _globals["_SENDMESSAGEREQUEST"]._serialized_end = 5689
    _globals["_GETTASKREQUEST"]._serialized_start = 5691
    _globals["_GETTASKREQUEST"]._serialized_end = 5790
    _globals["_LISTTASKSREQUEST"]._serialized_start = 5793
    _globals["_LISTTASKSREQUEST"]._serialized_end = 6102
    _globals["_LISTTASKSRESPONSE"]._serialized_start = 6105
    _globals["_LISTTASKSRESPONSE"]._serialized_end = 6237
    _globals["_CANCELTASKREQUEST"]._serialized_start = 6239
    _globals["_CANCELTASKREQUEST"]._serialized_end = 6288
    _globals["_GETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 6290
    _globals["_GETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 6358
    _globals["_DELETETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 6360
    _globals["_DELETETASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 6431
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 6434
    _globals["_SETTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 6590
    _globals["_SUBSCRIBETOTASKREQUEST"]._serialized_start = 6592
    _globals["_SUBSCRIBETOTASKREQUEST"]._serialized_end = 6646
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_start = 6648
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGREQUEST"]._serialized_end = 6758
    _globals["_GETEXTENDEDAGENTCARDREQUEST"]._serialized_start = 6760
    _globals["_GETEXTENDEDAGENTCARDREQUEST"]._serialized_end = 6805
    _globals["_SENDMESSAGERESPONSE"]._serialized_start = 6807
    _globals["_SENDMESSAGERESPONSE"]._serialized_end = 6905
    _globals["_STREAMRESPONSE"]._serialized_start = 6908
    _globals["_STREAMRESPONSE"]._serialized_end = 7117
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGRESPONSE"]._serialized_start = 7119
    _globals["_LISTTASKPUSHNOTIFICATIONCONFIGRESPONSE"]._serialized_end = 7237
    _globals["_A2ASERVICE"]._serialized_start = 7554
    _globals["_A2ASERVICE"]._serialized_end = 9408
# @@protoc_insertion_point(module_scope)
