.tabs.svelte-1f2pv7a{padding:1rem}.tab-list.svelte-1f2pv7a{display:flex;gap:.5rem;flex-wrap:wrap}.tab.svelte-1f2pv7a{padding:.4rem .75rem;border-radius:var(--radius-xl, 16px);border:1px solid var(--color-border, #f0ebe4);background:var(--color-tab-bg, #f2eee8);color:var(--color-tab-text, #5a534a);cursor:pointer;font-size:.8rem}.tab.active.svelte-1f2pv7a{background:var(--color-tab-active-bg, #e8f6f2);color:var(--color-tab-active-text, #106c67);border-color:var(--color-primary, #31a6a0)}.tab-panel.svelte-1f2pv7a{margin-top:1rem}.tabs.pills.svelte-1f2pv7a .tab:where(.svelte-1f2pv7a){border-radius:999px}.tabs.enclosed.svelte-1f2pv7a{border:1px solid var(--color-border, #f0ebe4);border-radius:var(--radius-2xl, 18px);background:var(--color-card-bg, #fcfaf7)}
