.accordion.svelte-1b7h7k8{padding:1rem}details.svelte-1b7h7k8{border:1px solid var(--color-border, #f0ebe4);border-radius:var(--radius-xl, 16px);padding:.75rem 1rem;margin-bottom:.5rem;background:var(--color-card-bg, #fcfaf7);box-shadow:var(--shadow-subtle, 0 4px 12px rgba(0, 0, 0, .04))}summary.svelte-1b7h7k8{cursor:pointer;font-weight:600;color:var(--color-text, #1f1f1f)}.panel.svelte-1b7h7k8{margin-top:.75rem}
